==> lowcode-shell-1.0.1.tgz: package/es/components/context-menu.js <==
import { createContextMenu, parseContextMenuAsReactNode, parseContextMenuProperties } from '@redhare/lowcode-utils';
import { engineConfig } from '@redhare/lowcode-editor-core';
import React from 'react';
export function ContextMenu(_ref) {
  var children = _ref.children,
    menus = _ref.menus,
    pluginContext = _ref.pluginContext;
  if (!engineConfig.get('enableContextMenu')) {
    return /*#__PURE__*/React.createElement(React.Fragment, null, children);
  }
  var handleContextMenu = function handleContextMenu(event) {
    event.preventDefault();
    event.stopPropagation();
    var destroyFn;
    var destroy = function destroy() {
      var _destroyFn;
      (_destroyFn = destroyFn) === null || _destroyFn === void 0 ? void 0 : _destroyFn();
    };
    var children = parseContextMenuAsReactNode(parseContextMenuProperties(menus, {
      destroy: destroy,
      pluginContext: pluginContext
    }), {
      pluginContext: pluginContext
    });
    if (!(children !== null && children !== void 0 && children.length)) {
      return;
    }
    destroyFn = createContextMenu(children, {
      event: event
    });
  };

  // 克隆 children 并添加 onContextMenu 事件处理器
  var childrenWithContextMenu = React.Children.map(children, function (child) {
    return /*#__PURE__*/React.cloneElement(child, {
      onContextMenu: handleContextMenu
    });
  });
  return /*#__PURE__*/React.createElement(React.Fragment, null, childrenWithContextMenu);
}
ContextMenu.create = function (pluginContext, menus, event) {
  var children = parseContextMenuAsReactNode(parseContextMenuProperties(menus, {
    pluginContext: pluginContext
  }), {
    pluginContext: pluginContext
  });
  if (!(children !== null && children !== void 0 && children.length)) {
    return;
  }
  return createContextMenu(children, {
    event: event
  });
};

==> lowcode-shell-1.3.4.tgz: package/es/components/context-menu.js <==
import { createContextMenu, parseContextMenuAsReactNode, parseContextMenuProperties } from '@kernelsoft/lowcode-utils';
import { engineConfig } from '@kernelsoft/lowcode-editor-core';
import React, { useCallback } from 'react';
export function ContextMenu(_ref) {
  var children = _ref.children,
    menus = _ref.menus,
    pluginContext = _ref.pluginContext;
  var handleContextMenu = useCallback(function (event) {
    event.preventDefault();
    event.stopPropagation();
    var destroyFn;
    var destroy = function destroy() {
      var _destroyFn;
      (_destroyFn = destroyFn) === null || _destroyFn === void 0 ? void 0 : _destroyFn();
    };
    var children = parseContextMenuAsReactNode(parseContextMenuProperties(menus, {
      destroy: destroy,
      pluginContext: pluginContext
    }), {
      pluginContext: pluginContext
    });
    if (!(children !== null && children !== void 0 && children.length)) {
      return;
    }
    destroyFn = createContextMenu(children, {
      event: event
    });
  }, [menus]);
  if (!engineConfig.get('enableContextMenu')) {
    return /*#__PURE__*/React.createElement(React.Fragment, null, children);
  }
  if (!menus || !menus.length) {
    return /*#__PURE__*/React.createElement(React.Fragment, null, children);
  }

  // 克隆 children 并添加 onContextMenu 事件处理器
  var childrenWithContextMenu = React.Children.map(children, function (child) {
    return /*#__PURE__*/React.cloneElement(child, {
      onContextMenu: handleContextMenu
    });
  });
  return /*#__PURE__*/React.createElement(React.Fragment, null, childrenWithContextMenu);
}
ContextMenu.create = function (pluginContext, menus, event) {
  var children = parseContextMenuAsReactNode(parseContextMenuProperties(menus, {
    pluginContext: pluginContext
  }), {
    pluginContext: pluginContext
  });
  if (!(children !== null && children !== void 0 && children.length)) {
    return;
  }
  return createContextMenu(children, {
    event: event
  });
};
